Welcome to ClientVPS Mirrors

Help for package RobustAdaptiveDecomposition
Type: Package
Title: Decomposes a Univariate Time Series into Subcomponents
Version: 0.1.0
Description: Provides a method to decompose a univariate time series into meaningful subcomponents for analysis and denoising.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-09-04 08:58:38 UTC; Dubai Computers
Author: Laiba Sultan Dar [aut, cre], Muhammad Aamir [aut], Muhammad Hamraz [aut]
Maintainer: Laiba Sultan Dar <laibasultan@awkum.edu.pk>
Repository: CRAN
Date/Publication: 2025-09-09 14:10:12 UTC

Divides the univariate time series data into subcomponents

Description

Divides the univariate time series data into subcomponents

Usage

RAD(data)

Arguments

data

A numeric vector containing the time series values.

Value

A data frame containing the decomposed IMFs and residual.

Examples

# Example usage:
sample_data <- rnorm(3000)
result <- RAD(sample_data)
head(result)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.